from enum import Enum


class SearchEngine(Enum):
    DUCKDUCKGO = 1,
    STARTPAGE = 2,
    BING = 3
